Summary:     oneAPI Threading Building Blocks (oneTBB)
Name:        tbb
Version:     2021.10.0
Release:     7%{?dist}
License:     ASL 2.0
URL:         https://github.com/oneapi-src/oneTBB
Source0:     https://github.com/intel/tbb/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:     tbb.pc
Source2:     tbbmalloc.pc
Source3:     tbbmalloc_proxy.pc

# https://github.com/oneapi-src/oneTBB/pull/1181
Patch5000:     Fix-suppress-warnings-on-gcc12.1-866.patch


BuildRequires: cmake gcc-c++ make
BuildRequires: python3-devel swig

%description
oneTBB is a flexible C++ library that simplifies the work
of adding parallelism to complex applications, even if you
are not a threading expert.

%package devel
Summary:  The Threading Building Blocks C++ headers and shared development libraries
Requires: %{name} = %{version}-%{release}

%description devel
Header files and shared object symlinks for the Threading Building
Blocks (TBB) C++ libraries.

%package -n python3-%{name}
Summary: Python 3 TBB module

%description -n python3-%{name}
Python 3 TBB module.


%prep
%autosetup -p1 -n oneTBB-%{version}
sed -i 's,env python,python3,' python/TBB.py python/tbb/__*.py
sed -i '/^#!/d' python/tbb/{pool,test}.py


%build
# https://github.com/oneapi-src/oneTBB/pull/1181
CXXFLAGS="$CXXFLAGS -Wno-error=stringop-overflow"
%cmake . -DTBB4PY_BUILD=ON
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_includedir}/rml
cp -p python/rml/*.h %{buildroot}%{_includedir}/rml

for file in %{SOURCE1} %{SOURCE2} %{SOURCE3}; do
    sed -i 's/%%{version}/%{version}/g' ${file}
    install -p -D -m 644 ${file} %{buildroot}%{_libdir}/pkgconfig/$(basename ${file})
done

%ifnarch loongarch64
%check
%if "%{python3_version}" >= "3.11"
%ctest --exclude-regex python_test
%else
%ctest
%endif
%endif


%files
%license CONTRIBUTING.md
%doc README.md
%{_libdir}/libtbb.so.*
%{_libdir}/libtbbmalloc.so.*
%{_libdir}/libtbbmalloc_proxy.so.*
%{_libdir}/libirml.so.*
%{_datadir}/doc/TBB/

%files devel
%doc cmake/README.md
%{_includedir}/rml/
%{_includedir}/tbb/
%{_includedir}/oneapi/
%{_libdir}/*.so
%{_libdir}/cmake/TBB/
%{_libdir}/pkgconfig/*.pc

%files -n python3-%{name}
%if "%{python3_version}" >= "3.11"
%{python3_sitearch}/*
%else
%{python3_sitearch}/TBB*
%{python3_sitearch}/tbb/
%{python3_sitearch}/__pycache__/TBB*
%endif

%changelog
* Thu Sep 19 2024 Sinong Chen <costinchen@tencent.com> - 2021.10.0-7
- Fix unexpanded macros in pc files

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2021.10.0-6
- Rebuilt for loongarch release

* Wed Jul 03 2024 Zhai Liangliang <zhailiangliang@loongson.cn> - 2021.10.0-5
- [Type] other
- [DESC] disable test for loongarch64

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2021.10.0-4
- Rebuilt for python 3.11

* Thu Sep 14 2023 Shuo Wang <abushwang@tencent.com> - 2021.10.0-3
- bypass python test for bootstrap
- update files for python package

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2021.10.0-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 cunshunxia <cunshunxia@tencent.com> - 2021.10.0-1
- upgrade to 2021.10.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2020.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2020.3-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Sep 20 2022 ZoeDong <zoedong@tencent.com> - 2020.3-1
- Initial build
